@@ -1,14 +1,11 @@
 # coding: utf-8
 
-from .html import TermsHTMLReconstructor
 from django.core.urlresolvers import resolve, Resolver404
 from .settings import TERMS_IGNORED_APPS, TERMS_DEBUG
+from .templatetags.terms import replace_terms
 
 
-class TermsMiddleware:
-    def __init__(self):
-        self.parser = TermsHTMLReconstructor()
-
+class TermsMiddleware(object):
     def process_response(self, request, response):
         url = request.path
         try:
@@ -23,11 +20,6 @@ class TermsMiddleware:
         is_html = 'text/html' in response['Content-Type']
 
         if not app_ignored and is_html and response.status_code == 200:
-            parser = self.parser
-            try:
-                parser.feed(response.content.decode('utf-8'))
-                response.content = parser.out
-            finally:
-                parser.reset()
+            response.content = replace_terms(response.content)
 
         return response
